@@ -9,7 +9,7 @@
 {-# LANGUAGE ConstraintKinds #-}
 -- | Allocate resources which are guaranteed to be released.
 --
--- For more information, see <https://www.fpcomplete.com/user/snoyberg/library-documentation/resourcet>.
+-- For more information, see <https://github.com/snoyberg/conduit/tree/master/resourcet#readme>.
 --
 -- One point to note: all register cleanup actions live in the @IO@ monad, not
 -- the main monad. This allows both more efficient code, and for monads to be
@@ -32,6 +32,7 @@ module Control.Monad.Trans.Resource
     , joinResourceT
       -- * Registering/releasing
     , allocate
+    , allocate_
     , register
     , release
     , unprotect
@@ -106,6 +107,22 @@ allocate :: MonadResource m
          -> m (ReleaseKey, a)
 allocate a = liftResourceT . allocateRIO a
 
+-- | Perform some allocation where the return value is not required, and
+-- automatically register a cleanup action.
+--
+-- @allocate_@ is to @allocate@ as @bracket_@ is to @bracket@
+--
+-- This is almost identical to calling the allocation and then
+-- @register@ing the release action, but this properly handles masking of
+-- asynchronous exceptions.
+--
+-- @since 1.2.4
+allocate_ :: MonadResource m
+          => IO a -- ^ allocate
+          -> IO () -- ^ free resource
+          -> m ReleaseKey
+allocate_ a = fmap fst . allocate a . const
+
 -- | Perform asynchronous exception masking.
 --
 -- This is more general then @Control.Exception.mask@, yet more efficient
